==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/KinesisAnalytics/InputProcessingConfigurationUpdate.pm <==
package Paws::KinesisAnalytics::InputProcessingConfigurationUpdate;
  use Moose;
  has InputLambdaProcessorUpdate => (is => 'ro', isa => 'Paws::KinesisAnalytics::InputLambdaProcessorUpdate', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::KinesisAnalytics::InputProcessingConfigurationUpdate

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::KinesisAnalytics::InputProcessingConfigurationUpdate object:

  $service_obj->Method(Att1 => { InputLambdaProcessorUpdate => $value, ..., InputLambdaProcessorUpdate => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::KinesisAnalytics::InputProcessingConfigurationUpdate object:

  $result = $service_obj->Method(...);
  $result->Att1->InputLambdaProcessorUpdate

=head1 DESCRIPTION

Describes updates to an InputProcessingConfiguration.

=head1 ATTRIBUTES


=head2 B<REQUIRED> InputLambdaProcessorUpdate => L<Paws::KinesisAnalytics::InputLambdaProcessorUpdate>

  Provides update information for an InputLambdaProcessor.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::KinesisAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/KinesisAnalytics/InputProcessingConfigurationUpdate.pm <==
package Paws::KinesisAnalytics::InputProcessingConfigurationUpdate;
  use Moose;
  has InputLambdaProcessorUpdate => (is => 'ro', isa => 'Paws::KinesisAnalytics::InputLambdaProcessorUpdate', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::KinesisAnalytics::InputProcessingConfigurationUpdate

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::KinesisAnalytics::InputProcessingConfigurationUpdate object:

  $service_obj->Method(Att1 => { InputLambdaProcessorUpdate => $value, ..., InputLambdaProcessorUpdate => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::KinesisAnalytics::InputProcessingConfigurationUpdate object:

  $result = $service_obj->Method(...);
  $result->Att1->InputLambdaProcessorUpdate

=head1 DESCRIPTION

Describes updates to an InputProcessingConfiguration.

=head1 ATTRIBUTES


=head2 B<REQUIRED> InputLambdaProcessorUpdate => L<Paws::KinesisAnalytics::InputLambdaProcessorUpdate>

  Provides update information for an InputLambdaProcessor.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::KinesisAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
